; The CMD file.
;
; Two parts: 1. Command definition and  2. State entry
; (state entry is after the commands def section)
;
; 1. Command definition
; ---------------------
; Note: The commands are CASE-SENSITIVE, and so are the command names.
; The eight directions are:
;   B, DB, D, DF, F, UF, U, UB     (all CAPS)
;   corresponding to back, down-back, down, downforward, etc.
; The six buttons are:
;   a, b, c, x, y, z               (all lower case)
;   In default key config, abc are are the bottom, and xyz are on the
;   top row. For 2 button characters, we recommend you use a and b.
;   For 6 button characters, use abc for kicks and xyz for punches.
;
; Each [Command] section defines a command that you can use for
; state entry, as well as in the CNS file.
; The command section should look like:
;
;   [Command]
;   name = some_name
;   command = the_command
;   time = time (optional)
;   buffer.time = time (optional)
;
; - some_name
;   A name to give that command. You'll use this name to refer to
;   that command in the state entry, as well as the CNS. It is case-
;   sensitive (QCB_a is NOT the same as Qcb_a or QCB_A).
;
; - command
;   list of buttons or directions, separated by commas. Each of these
;   buttons or directions is referred to as a "symbol".
;   Directions and buttons can be preceded by special characters:
;   slash (/) - means the key must be held down
;          egs. command = /D       ;hold the down direction
;               command = /DB, a   ;hold down-back while you press a
;   tilde (~) - to detect key releases
;          egs. command = ~a       ;release the a button
;               command = ~D, F, a ;release down, press fwd, then a
;          If you want to detect "charge moves", you can specify
;          the time the key must be held down for (in game-ticks)
;          egs. command = ~30a     ;hold a for at least 30 ticks, then release
;   dollar ($) - Direction-only: detect as 4-way
;          egs. command = $D       ;will detect if D, DB or DF is held
;               command = $B       ;will detect if B, DB or UB is held
;   plus (+) - Buttons only: simultaneous press
;          egs. command = a+b      ;press a and b at the same time
;               command = x+y+z    ;press x, y and z at the same time
;   greater-than (>) - means there must be no other keys pressed or released
;                      between the previous and the current symbol.
;          egs. command = a, >~a   ;press a and release it without having hit
;                                  ;or released any other keys in between
;   You can combine the symbols:
;     eg. command = ~30$D, a+b     ;hold D, DB or DF for 30 ticks, release,
;                                  ;then press a and b together
;
;   Note: Successive direction symbols are always expanded in a manner similar
;         to this example:
;           command = F, F
;         is expanded when MUGEN reads it, to become equivalent to:
;           command = F, >~F, >F
;
;   It is recommended that for most "motion" commads, eg. quarter-circle-fwd,
;   you start off with a "release direction". This makes the command easier
;   to do.
;
; - time (optional)
;   Time allowed to do the command, given in game-ticks. The default
;   value for this is set in the [Defaults] section below. A typical
;   value is 15.
;
; - buffer.time (optional)
;   Time that the command will be buffered for. If the command is done
;   successfully, then it will be valid for this time. The simplest
;   case is to set this to 1. That means that the command is valid
;   only in the same tick it is performed. With a higher value, such
;   as 3 or 4, you can get a "looser" feel to the command. The result
;   is that combos can become easier to do because you can perform
;   the command early. Attacks just as you regain control (eg. from
;   getting up) also become easier to do. The side effect of this is
;   that the command is continuously asserted, so it will seem as if
;   you had performed the move rapidly in succession during the valid
;   time. To understand this, try setting buffer.time to 30 and hit
;   a fast attack, such as KFM's light punch.
;   The default value for this is set in the [Defaults] section below.
;   This parameter does not affect hold-only commands (eg. /F). It
;   will be assumed to be 1 for those commands.
;
; If you have two or more commands with the same name, all of them will
; work. You can use it to allow multiple motions for the same move.
;
; Some common commands examples are given below.
;
; [Command] ;Quarter circle forward + x
; name = "QCF_x"
; command = ~D, DF, F, x
;
; [Command] ;Half circle back + a
; name = "HCB_a"
; command = ~F, DF, D, DB, B, a
;
; [Command] ;Two quarter circles forward + y
; name = "2QCF_y"
; command = ~D, DF, F, D, DF, F, y
;
; [Command] ;Tap b rapidly
; name = "5b"
; command = b, b, b, b, b
; time = 30
;
; [Command] ;Charge back, then forward + z
; name = "charge_B_F_z"
; command = ~60$B, F, z
; time = 10
;
; [Command] ;Charge down, then up + c
; name = "charge_D_U_c"
; command = ~60$D, U, c
; time = 10


;-| Button Remapping |-----------------------------------------------------
; This section lets you remap the player's buttons (to easily change the
; button configuration). The format is:
;   old_button = new_button
; If new_button is left blank, the button cannot be pressed.
[Remap]
x = x
y = y
z = z
a = a
b = b
c = c
s = s

;-| Default Values |-------------------------------------------------------
[Defaults]
; Default value for the "time" parameter of a Command. Minimum 1.
command.time = 15

; Default value for the "buffer.time" parameter of a Command. Minimum 1,
; maximum 30.
command.buffer.time = 1


;-| Super Motions |--------------------------------------------------------
;The following two have the same name, but different motion.
;Either one will be detected by a "command = TripleKFPalm" trigger.
;Time is set to 20 (instead of default of 15) to make the move
;easier to do.
;

[Command]
name = "MoeMoeKyun"
command = ~B, F, B, F, xy
time = 20

[Command]
name = "DeadlySyrupAir"
command = ~D, DF, F, D, DF, F, a
time = 20


[Command]
name = "DeadlySyrupAir"
command = ~D, DF, F, D, DF, F, b
time = 20

[Command]
name = "DeadlySyrup"
command = ~D, DB, B, D, DB, B, a
time = 20

[Command]
name = "DeadlySyrup"
command = ~D, DB, B, D, DB, B, a
time = 20

[Command]
name = "DeadlySyrup"
command = ~D, DB, B, D, DB, B, b
time = 20

[Command]
name = "HyperSugarCrush"
command = ~D, DF, F, D, DF, F, a
time = 20

[Command]
name = "HyperSugarCrush"
command = ~D, DF, F, D, DF, F, b
time = 20

[Command]
name = "Heartwave"
command = ~D, DF, F, D, DF, F, x
time = 20

[Command]
name = "Heartwave"   ;Same name as above
command = ~D, DF, F, D, DF, F, y
time = 20


;-| Special Motions |------------------------------------------------------
[Command]
name = "HCB_a"
command = ~F, DF, D, DB, B, a

[Command]
name = "HCB_b"
command = ~F, DF, D, DB, B, b

[Command]
name = "QCF_xy"
command = ~D, DF, F, x+y

[Command]
name = "QCF_x"
command = ~D, DF, F, x

[Command]
name = "QCF_y"
command = ~D, DF, F, y

[Command]
name = "QCB_xy"
command = ~D, DB, B, x+y

[Command]
name = "QCB_x"
command = ~D, DB, B, x

[Command]
name = "QCB_y"
command = ~D, DB, B, y

[Command]
name = "QCF_ab"
command = ~D, DF, F, a+b

[Command]
name = "QCF_a"
command = ~D, DF, F, a

[Command]
name = "QCF_b"
command = ~D, DF, F, b

[Command]
name = "QCB_a"
command = ~D, DB, B, a

[Command]
name = "QCB_b"
command = ~D, DB, B, b

;-| Double Tap |-----------------------------------------------------------
[Command]
name = "FF"     ;Required (do not remove)
command = F, F
time = 10

[Command]
name = "BB"     ;Required (do not remove)
command = B, B
time = 10

;-| 2/3 Button Combination |-----------------------------------------------
[Command]
name = "recovery";Required (do not remove)
command = z
time = 1

;-| Single Button |---------------------------------------------------------
[Command]
name = "a"
command = a
time = 1

[Command]
name = "b"
command = b
time = 1

[Command]
name = "c"
command = c
time = 1

[Command]
name = "x"
command = x
time = 1

[Command]
name = "y"
command = y
time = 1

[Command]
name = "z"
command = z
time = 1

[Command]
name = "start"
command = s
time = 1

;-| Hold Dir |--------------------------------------------------------------
[Command]
name = "holdfwd";Required (do not remove)
command = /$F
time = 1

[Command]
name = "holdback";Required (do not remove)
command = /$B
time = 1

[Command]
name = "holdup" ;Required (do not remove)
command = /$U
time = 1

[Command]
name = "holddown";Required (do not remove)
command = /$D
time = 1

;---------------------------------------------------------------------------
; 2. State entry
; --------------
; This is where you define what commands bring you to what states.
;
; Each state entry block looks like:
;   [State -1, Label]           ;Change Label to any name you want to use to
;                               ;identify the state with.
;   type = ChangeState          ;Don't change this
;   value = new_state_number
;   trigger1 = command = command_name
;   . . .  (any additional triggers)
;
; - new_state_number is the number of the state to change to
; - command_name is the name of the command (from the section above)
; - Useful triggers to know:
;   - statetype
;       S, C or A : current state-type of player (stand, crouch, air)
;   - ctrl
;       0 or 1 : 1 if player has control. Unless "interrupting" another
;                move, you'll want ctrl = 1
;   - stateno
;       number of state player is in - useful for "move interrupts"
;   - movecontact
;       0 or 1 : 1 if player's last attack touched the opponent
;                useful for "move interrupts"
;
; Note: The order of state entry is important.
;   State entry with a certain command must come before another state
;   entry with a command that is the subset of the first.
;   For example, command "fwd_a" must be listed before "a", and
;   "fwd_ab" should come before both of the others.
;
; For reference on triggers, see CNS documentation.
;
; Just for your information (skip if you're not interested):
; This part is an extension of the CNS. "State -1" is a special state
; that is executed once every game-tick, regardless of what other state
; you are in.
[Statedef 955531] ;Mio's AI
Ctrl = 0
anim = 0

[state -1, Shut Down]
Type = DestroySelf
Trigger1 = 0; !Root, AILevel
IgnoreHitPause = 1

[state -1, Variable Reset]
Type = VarSet
IgnoreHitPause = 1
FV = (0)
TriggerAll = Fvar(0) = fvar(1)
Trigger1 = root,stateno = [6060,6069]
Trigger2 = root, time = 1
trigger3 = !root,animtime
Trigger4 = enemy, time = 1
trigger5 = 1; debug
Value = 0  

;Dedicated Buffer Delegation
[State 955531]
Type = Null
IgnoreHitPause = 1
TriggerAll = Root, AILevel
TriggerAll = Root, Alive
triggerall = numenemy
;Tick Throw Walk - Low Kick
Trigger1 = Root, StateNo = 430
Trigger1 = Root, MoveGuarded = 1
;Tick Throw Walk
Trigger2 = Root, Ctrl || Root, StateNo = 20
Trigger2 = var(59) > 0
;Air Combo
Trigger3 = Root, StateNo = [6060,6061]
Trigger3 = P2StateNo = 5020 || P2StateNo = 5030 || P2StateNo = 5050
Trigger4 = Root, Ctrl
Trigger4 = !var(57)
trigger4 = roundstate = 2
Trigger5 = Var(58) > 0
Trigger6 = var(59) < 0
Trigger7 = var(58) < 0
Trigger8 = var(57)
;------------------------------------------
Trigger1 = pi||var(59) := 10
Trigger2 = pi||var(59) := var(59) - cond( Enemy, Ctrl, 2, 1 )
Trigger3 = pi||var(58) := 15
Trigger4 = pi||var(57) := ((10 + random%40) * cond(random<337&& root,frontedgebodydist>2*30,1,-1))
Trigger5 = pi||var(58) := var(58) - 1
Trigger6 = pi||var(59) := 0
Trigger7 = pi||var(58) := 0
Trigger8 = pi||var(57) := var(57) + cond(var(57)<0,1,-1)
;------------------------------------------
Trigger1 = 0
Trigger2 = 0
Trigger3 = 0
Trigger4 = 0
Trigger5 = 0
Trigger6 = 0
Trigger7 = 0
Trigger8 = 0

[state 955531, Full AI Programming, Close Range Anti-Projectile]
Type = Null
IgnoreHitPause = 1
TriggerAll	=	IsHelper
triggerall	=	Root, p2dist X >= 0
TriggerAll	=	RootDist X = [-70,70]
TriggerAll	=	P2MoveType = A
TriggerAll	=	P2StateNo >= 1000
TriggerAll	=	!( Enemy, HitDefAttr = SCA , AA )
TriggerAll	=	InGuardDist
TriggerAll	=	!fvar(4) ;Dizzy Cancel Check
TriggerAll	=	!fvar(5) ;Guard Check
Triggerall	=	fvar(0) = 0 || Random < 100  ;AI only
triggerall	=	roundstate=2   ;Only when fighting
triggerall	=	Root, alive           ;Only when alive
TriggerAll	=	Root, AILevel
TriggerAll	=	Root, StateType != A;	;Set for appropriate StateType
triggerall	=	Root, ctrl||Root, StateNo = 100||root, StateNo = [120,140]
TriggerAll	=	Enemy, Time <= abs(ceil(fvar(2)/2) - root,p2dist x) && Root, Time <= 4
Trigger1	=	Root, P2BodyDist X < 2*100
trigger1	=	random<100
Trigger2	=	Root, P2BodyDist X < 2*130
trigger2	=	random<100
Trigger2	=	Root, StateNo != [120,159]
Trigger3	=	Root, p2bodydist X >= 2*100&&!Root,InGuardDist 
;-----------------------|	Option Select	|-----------------------------
Trigger1	=	pi||floor(fvar(0) := 1030)
Trigger2	=	pi||floor(fvar(0) := 1130)
Trigger3	=	pi||floor(fvar(0) := 40)   
;-----------------------|	"Zero" Trigger	|-----------------------------
Trigger1	=	0
Trigger2	=	0
Trigger3	=	0
Trigger4	=	0
Trigger5	=	0
Trigger6	=	0
Trigger7	=	0
Trigger8	=	0 

[state 955531, Full AI Programming, Max Range Anti-Projectile]
Type = Null
IgnoreHitPause = 1
TriggerAll	=	IsHelper
triggerall	=	Root, p2dist X >= 0
TriggerAll	=	RootDist X < -70
TriggerAll	=	P2MoveType = A
TriggerAll	=	P2StateNo >= 1000
TriggerAll	=	!( Enemy, HitDefAttr = SCA , AA )
TriggerAll	=	InGuardDist
TriggerAll	=	!fvar(4) ;Dizzy Cancel Check
TriggerAll	=	!fvar(5) ;Guard Check
Triggerall	=	fvar(0) = 0 || Random < 100  ;AI only
triggerall	=	roundstate=2   ;Only when fighting
triggerall	=	Root, alive           ;Only when alive
TriggerAll	=	Root, AILevel
TriggerAll	=	Root, StateType != A;	;Set for appropriate StateType
triggerall	=	Root, ctrl||Root, StateNo = 100||root, StateNo = [120,140]
TriggerAll	=	Enemy, Time <= abs(ceil(fvar(2)) - root,p2dist x) && Root, Time <= 2
Trigger1	=	Root, P2BodyDist X >= 2*100
trigger1	=	random<200&&!Root,InGuardDist
Trigger2	=	Root, P2BodyDist X >= 2*130
trigger2	=	random<200&&Root,InGuardDist
;Trigger2	=	Root, StateNo != [120,159]
Trigger3	=	Root, p2bodydist X >= 2*100&&!Root,InGuardDist 
;-----------------------|	Option Select	|-----------------------------
Trigger1	=	pi||floor(fvar(0) := 1040)
Trigger2	=	pi||floor(fvar(0) := 1130) 
Trigger3	=	pi||floor(fvar(0) := 40)   
;-----------------------|	"Zero" Trigger	|-----------------------------
Trigger1	=	0
Trigger2	=	0
Trigger3	=	0
Trigger4	=	0
Trigger5	=	0
Trigger6	=	0
Trigger7	=	0
Trigger8	=	0

[state 955531, Full AI Programming, Anti-Air]
Type = Null
IgnoreHitPause = 1
TriggerAll	=	IsHelper
triggerall	=	Root, p2bodydist X >= 0
triggerall	=	!InGuardDist&&!Root, InGuardDist||Enemy, time>=10         ;Not within guard distance
Triggerall	=	fvar(0) = 0 || Random < 100  ;AI only
triggerall	=	roundstate=2   ;Only when fighting
triggerall	=	Root, alive           ;Only when alive
TriggerAll	=	Root, AILevel
trigger1	=	Root, p2bodydist x < 2*20
Trigger1	=	Root, StateType != A;	;Set for appropriate StateType
trigger1	=	Root, ctrl
trigger1	=	p2stateno !=[5000,5300]
trigger1	=	p2statetype=A
trigger1	=	enemy, vel y >= -2*2
trigger1	=	enemy, pos y < -20
trigger2	=	Root, p2bodydist x < 2*30
Trigger2	=	Root, StateType = A;	;Set for appropriate StateType
trigger2	=	Root, ctrl
trigger2	=	p2stateno !=[5000,5300]
trigger2	=	p2statetype=A
;----------------------------------------------------------------------
Trigger1	=	pi||floor(fvar(0) := 410)
Trigger2	=	pi||floor(fvar(0) := cond( root, p2dist y < 0, 600, 630 ))
;----------------------------------------------------------------------
Trigger1 = 0
Trigger2 = 0
Trigger3 = 0
Trigger4 = 0
Trigger5 = 0
Trigger6 = 0
Trigger7 = 0
Trigger8 = 0

[state 955531, Full AI Programming, Air to Air]
Type = Null
IgnoreHitPause = 1
TriggerAll	=	IsHelper
triggerall	=	Root, p2dist X >= 0
TriggerAll	=	Root, StateType = A
triggerall	=	!InGuardDist&&!Root, InGuardDist||Enemy, time>=10         ;Not within guard distance
TriggerAll	=	fvar(0) = 0 || Random < 160  ;AI only
triggerall	=	roundstate=2   ;Only when fighting
triggerall	=	Root, alive           ;Only when alive
TriggerAll	=	Root, AiLevel
Trigger1 = Root, p2bodydist x <= 2*41
Trigger1 = Root, vel y >= -1.9
Trigger1 = P2StateType = S
Trigger2 = Root, StateNo = 630
Trigger2 = Root, MoveContact = 1
Trigger3 = Root, StateNo = 600
Trigger3 = Root, MoveContact = 1
;----------------------------------------------------------------------
Trigger1 = pi||floor(fvar(0) := 630)
Trigger2 = pi||floor(fvar(0) := 640)
Trigger3 = pi||floor(fvar(0) := 610)
;----------------------------------------------------------------------
Trigger1 = 0
Trigger2 = 0
Trigger3 = 0
Trigger4 = 0
Trigger5 = 0
Trigger6 = 0
Trigger7 = 0
Trigger8 = 0


[state 955531, Full AI Programming, Dizzy Cancel Buffer]
Type = Null
IgnoreHitPause = 1
TriggerAll	=	IsHelper
triggerall	=	Root, p2dist X >= 0
triggerall	=	var(0) > 0
triggerall	=	!InGuardDist&&!Root, InGuardDist||Enemy, time>=ceil(fvar(2) / 4)
TriggerAll	=	fvar(0) = 0 || Random < 160  ;AI only
triggerall	=	roundstate=2   ;Only when fighting
triggerall	=	Root, alive           ;Only when alive
TriggerAll	=	Root, AILevel
triggerAll	=	Root, Time <= var(0) && Root, Ctrl 
TriggerAll	=	 !fvar(3) 
trigger1	=	Root, p2bodydist x <= 2*35 
Trigger1	=	Root, StateType != A;	;Set for appropriate StateType
Trigger1	=	p2statetype = S || P2StateType = C
Trigger2	=	Root, P2BodyDist X<=2*90  ;Horizontal distance (maximum range)
Trigger2	=	Root, StateType != A;	;Set for appropriate StateType
Trigger2	=	P2StateType != A   ;vertical distance (non-anti-air situations)
trigger2	=	Root, p2bodydist x > 2*35 ;randomizer
trigger2	=	P2StateNo != 5050 ;not in hitfall
trigger2	=	p2statetype!=L         ;standard state conditions
;----------------------------------------------------------------------
trigger1	=	pi||floor(fvar(0) := 430)
trigger2	=	pi||floor(fvar(0) := 210)
;----------------------------------------------------------------------
Trigger1 = 0
Trigger2 = 0
Trigger3 = 0
Trigger4 = 0
Trigger5 = 0

[state 955531, Full AI Programming, Guard Stagger]
Type = Null
IgnoreHitPause = 1
TriggerAll	=	IsHelper
triggerall	=	Root, p2dist X >= 0
TriggerAll	=	fvar(0) = 0 || Random < 160  ;AI only
triggerall	=	roundstate=2   ;Only when fighting
triggerall	=	Root, alive           ;Only when alive
TriggerAll	=	Root, AILevel && Root, AILevel > 6
Triggerall	=	Root, StateNo != [120,159]
triggerAll	=	Root, ctrl && !fvar(3) 
TriggerAll	=	P2StateNo = 140 || P2StateNo = 151 || P2StateNo = 153 || (P2StateNo = [130,131])
trigger1	=	Root, p2bodydist x <= 2*45
Trigger1	=	Root, StateType != A;	;Set for appropriate StateType
Trigger1	=	p2statetype = S || P2StateType = C
Trigger2	=	Root, P2BodyDist X<=2*90+random%9  ;Horizontal distance (maximum range)
Trigger2	=	Root, StateType != A;	;Set for appropriate StateType
Trigger2	=	P2StateType != A   ;vertical distance (non-anti-air situations)
trigger2	=	random < 120 ;randomizer
trigger2	=	P2StateNo != 5050 ;not in hitfall
trigger2	=	P2MoveType = I
trigger2	=	p2statetype!=L         ;standard state conditions
Trigger3	=	P2StateType = A
;----------------------------------------------------------------------
trigger1	=	pi||floor(fvar(0) := 430+cond(random<30&&root, p2bodydist X > 35,10,0))
trigger2	=	pi||floor(fvar(0) := 210)
trigger3	=	pi||floor(fvar(0) := 1000)
;----------------------------------------------------------------------
Trigger1 = 0
Trigger2 = 0
Trigger3 = 0
Trigger4 = 0
Trigger5 = 0
[state 955531, Full AI Programming, Hit Link]
Type = Null
IgnoreHitPause = 1
TriggerAll	=	IsHelper
triggerall	=	Root, p2dist X >= 0
TriggerAll	=	fvar(0) = 0 || Random < 160  ;AI only
triggerall	=	roundstate=2   ;Only when fighting
triggerall	=	Root, alive           ;Only when alive
TriggerAll	=	Root, AILevel && Root, AILevel > 6
Triggerall	=	Root, StateNo != [120,159]
triggerAll	=	Root, ctrl && !fvar(3) 
TriggerAll	=	P2StateNo = 5001 || P2StateNo = 5011 || P2StateNo != 5035 && (P2StateNo = [5020,5040])
trigger1	=	Root, p2bodydist x <= 2*35
Trigger1	=	p2statetype = S || P2StateType = C
Trigger1	=	Root, StateType != A;	;Set for appropriate StateType
Trigger2	=	Root, P2BodyDist X<=2*90+random%9  ;Horizontal distance (maximum range)
Trigger2	=	Root, StateType != A;	;Set for appropriate StateType
Trigger2	=	P2StateType != A   ;vertical distance (non-anti-air situations)
trigger2	=	random < 120 ;randomizer
trigger2	=	!var(59)
trigger2	=	P2StateNo != 5050 ;not in hitfall
trigger2	=	P2MoveType = I
trigger2	=	p2statetype!=L         ;standard state conditions
trigger3	=	P2MoveType = H
Trigger3	=	P2StateType = A
;----------------------------------------------------------------------
trigger1	=	pi||floor(fvar(0) := 430+cond(random<30&&root, p2bodydist X > 2*35,10,0))
trigger2	=	pi||floor(fvar(0) := 210)
trigger3	=	pi||floor(fvar(0) := 1000)
;----------------------------------------------------------------------
Trigger1 = 0
Trigger2 = 0
Trigger3 = 0
Trigger4 = 0
Trigger5 = 0

[state 955531, Full AI Programming, Standard]
Type = Null
IgnoreHitPause = 1
TriggerAll	=	IsHelper
triggerall	=	Root, p2dist X >= 0
triggerall	=	!InGuardDist&&!Root, InGuardDist||Enemy, time>=ceil(fvar(2) / 4)
TriggerAll	=	fvar(0) = 0 || Random < 160  ;AI only
triggerall	=	roundstate=2   ;Only when fighting
triggerall	=	Root, alive           ;Only when alive
TriggerAll	=	Root, AILevel
TriggerAll	=	P2MoveType != H || Root, PrevStateNo = 52 && Root, Time <= 4
triggerAll	=	Root, StateNo != [120,159] 
triggerAll	=	Root, ctrl && !fvar(3) 
trigger1	=	root, time <= 4
Trigger1	=	P2MoveType != H
trigger1	=	p2statetype=S||p2statetype=C
trigger1	=	p2stateno !=[5000,5300]
trigger1	=	Root, p2bodydist x < 2*3
Trigger1	=	Root, StateType != A;	;Set for appropriate StateType
trigger2	=	(Root, p2bodydist x = [2*3,2*45]) && ((random < 240 || Root, AILevel > 7) || (P2StateNo = [120,159])) || (Root, P2BodyDist X =(2*45,2*110]) && random < 200 && Enemy, Ctrl
trigger2	=	root, time<=8
Trigger2	=	p2statetype = S || P2StateType = C
Trigger2	=	Root, StateType != A;	;Set for appropriate StateType
trigger3	=	random < 120 ;randomizer
Trigger3	=	Root, P2BodyDist X<=2*90+random%9  ;Horizontal distance (maximum range)
trigger3	=	P2MoveType = I
trigger3	=	p2statetype!=L         ;standard state conditions
Trigger3	=	P2StateType != A   ;vertical distance (non-anti-air situations)
Trigger3	=	Root, StateType != A;	;Set for appropriate StateType
trigger3	=	P2StateNo != 5050 ;not in hitfall
trigger3	=	!var(59)
Trigger4	=	random < 40 + (p2dist x - p2bodydist x) 
;This was just 60 before, keep p2dist x - p2bodydist x in mind for later 
trigger4	=	root, time<=2
Trigger4	=	P2MoveType = I
Trigger4	=	p2statetype = S 
Trigger4	=	P2BodyDist X >= 2*85
Trigger4	=	Root, StateType != A;	;Set for appropriate StateType
Trigger5	=	Random<50 
trigger5	=	root, time<=2
trigger5	=	 P2MoveType = I
trigger5	=	 P2StateType = L
trigger5	=	 Enemy, time >= fvar(2) - 25
trigger5	=	Root, p2bodydist x <= 2*170
Trigger5	=	Root, StateType != A;	;Set for appropriate StateType
;----------------------------------------------------------------------
trigger1	=	pi||floor(fvar(0) := 800)
trigger2	=	pi||floor(fvar(0) := cond( root, p2bodydist x <= 2*15, 230, 430+cond(random<30&&root, p2bodydist X > 2*45,10,0) ))
trigger3	=	pi||floor(fvar(0) := 210)
trigger4	=	pi||floor(fvar(0) := cond(Root, p2bodydist X <= 2*105,1000,1010))
trigger5	=	pi||floor(fvar(0) := cond(Root, p2bodydist X <= 2*105,1000,1010))
;----------------------------------------------------------------------
Trigger1 = 0
Trigger2 = 0
Trigger3 = 0
Trigger4 = 0
Trigger5 = 0

[state 955531, Full AI Programming, Supers]
Type = Null
IgnoreHitPause = 1
TriggerAll	=	IsHelper
TriggerAll	=	fvar(0) = 0 || Random < 100    ;AI only
triggerall	=	roundstate=2   ;Only when fighting
triggerall	=	Root, alive           ;Only when alive
triggerall	=	power >= 1000
TriggerAll	=	Root, AILevel
trigger1	=	random < 250 * (1 * Root, var(3))
Trigger1	=	Root, StateNo = 210 || Root, StateNo = 235 && Root, HitCount > 1
trigger1	=	Root, MoveHit = 1
trigger2	=	Enemy, vel y >= (p2statetype = A)
trigger2	=	Root, inguarddist&&inguarddist
trigger2	=	Root, p2bodydist x < 2*90
trigger2	=	Root, p2dist x >= 0
Trigger2	=	Root, P2Dist Y >= 2*-30
trigger2	=	Root, ctrl
;----------------------------------------------------------------------
trigger1	=	pi||floor(fvar(0) := 3020-20*(RootDist X = [-80,50])) 
trigger2	=	pi||floor(fvar(0) := 3010)
;----------------------------------------------------------------------
Trigger1 = 0
Trigger2 = 0
Trigger3 = 0
Trigger4 = 0
Trigger5 = 0
Trigger6 = 0
Trigger7 = 0
Trigger8 = 0

[state 955531, Full AI Programming, MoveContact]
Type = Null
IgnoreHitPause = 1
TriggerAll	=	IsHelper
TriggerAll	=	fvar(0) = 0 || Random < 120   ;AI only
triggerAll	=	Root, MoveHit = 1 || (Random < 6 ** Root, MoveGuarded)
triggerall	=	roundstate=2   ;Only when fighting
triggerall	=	Root, alive           ;Only when alive
TriggerAll	=	Root, AILevel
trigger1	=	P2StateNo != [120,159]
Trigger1	=	Root, StateNo = 210 || Root, StateNo = 235 && Root, Time > 25 || Root, StateNo = 440                      ;combo condition
trigger2	=	random <= cond( root, moveguarded, 200, 1000)
Trigger2	=	Root, StateNo = 230 || Root, StateNo = 200 || Root, StateNo = 400 || Root, StateNo = 430
Trigger3	=	Root, StateNo = 230                      ;combo condition
Trigger4	=	Root, StateNo = 410                      ;combo condition
;----------------------------------------------------------------------
trigger1	=	pi||floor(fvar(0) := cond((enemy, const(size.head.pos.y) < -50), cond(p2statetype!=C&&random<667,1150,cond(p2statetype=C&&Root, stateno!=235,1000,1110)), 1000))
trigger2	=	pi||floor(fvar(0) := cond((enemy, const(size.head.pos.y) < -50), cond(random<400,235,210), 440))
trigger3	=	pi||floor(fvar(0) := 210)
trigger4	=	pi||floor(fvar(0) := 1000)
;----------------------------------------------------------------------
Trigger1 = 0
Trigger2 = 0
Trigger3 = 0
Trigger4 = 0
Trigger5 = 0
Trigger6 = 0
Trigger7 = 0
Trigger8 = 0

[state 955531, Full AI Programming, Movement]
Type = Null
IgnoreHitPause = 1
TriggerAll	=	IsHelper
triggerall	=	Root, p2dist X >= 0
triggerall	=	!InGuardDist&&!Root, InGuardDist         ;Not within guard distance
TriggerAll	=	fvar(0) = 0 || Random < 100   ;AI only
triggerall	=	roundstate=2   ;Only when fighting
triggerall	=	Root, alive           ;Only when alive
TriggerAll	=	Root, AILevel
triggerAll	=	Root, ctrl
TriggerAll	=	Root, StateType = S;	;Set for appropriate StateType
triggerAll	=	Root, StateNo != [120,159] 
trigger1	=	 Random < 200
trigger1	=	 root, Time <=7
trigger1	=	 P2StateNo = [5050,5110]
trigger2	=	random < cond(P2StateNo >= 160 && P2StateNo != 5120, 400, 80) || enemy, facing = facing
trigger2	=	 root, Time <=7
Trigger2	=	P2MoveType = I
trigger2	=	Root, P2BodyDist X > 2*100
trigger3	=	 random < 100 
trigger3	=	 Root, Time <= 4
Trigger3	=	P2MoveType = I
trigger3	=	 P2StateType = L
Trigger3	=	Root, P2BodyDist X < 2*60
trigger4	=	 Enemy, hitdefattr = , AT
;----------------------------------------------------------------------
trigger1	=	pi||floor(fvar(0) := 100)
trigger2	=	pi||floor(fvar(0) := 100)
trigger3	=	pi||floor(fvar(0) := 105)
trigger4	=	pi||floor(fvar(0) := 105)
;----------------------------------------------------------------------
Trigger1 = 0
Trigger2 = 0
Trigger3 = 0
Trigger4 = 0
Trigger5 = 0
Trigger6 = 0
Trigger7 = 0
Trigger8 = 0

[state 955531, Full AI Programming, Dizzy Cancels]
Type = Null
IgnoreHitPause = 1
TriggerAll	=	IsHelper
TriggerAll	=	fvar(0) = 0 || Random < 100   ;AI only
triggerAll	=	Root, MoveHit 
TriggerAll	=	Root, StateNo != [6060,6062]
TriggerAll	=	Root, MoveType = A
triggerall	=	roundstate=2   ;Only when fighting
triggerall	=	Root, alive           ;Only when alive
triggerall	=	power >= cond( Root, AILevel > 6, 550, 1000 ) 
TriggerAll	=	root, var(3) < 3
TriggerAll	=	Root, AILevel
Trigger1	=	random <= ceil(1000 / (1 + Root, var(3)))
Trigger1	=	Root, StateNo = 1110  
trigger1	=	Root, HitCount = 5                        ;combo condition
Trigger2	=	Enemy, Life < 300 || random <= ceil(800 / (1 + Root, var(3)))
Trigger2	=	Root, StateNo = 1152
;----------------------------------------------------------------------
trigger1	=	pi||floor(fvar(0) := 6060 && var(0) := 12) 
trigger2	=	pi||floor(fvar(0) := 6060 && var(0) := 12)
;----------------------------------------------------------------------
Trigger1 = 0
Trigger2 = 0
Trigger3 = 0
Trigger4 = 0
Trigger5 = 0
Trigger6 = 0
Trigger7 = 0
Trigger8 = 0

[state 955531, Full AI Programming, Jump]
Type = Null
IgnoreHitPause = 1
TriggerAll	=	IsHelper
triggerall	=	Root, p2dist X >= 0
TriggerAll	=	fvar(0) = 0 || Random < 100   ;AI only
triggerall	=	root, time <= 2
triggerall	=	roundstate=2   ;Only when fighting
triggerall	=	Root, alive           ;Only when alive
TriggerAll	=	Root, AILevel
Triggerall	=	Root, StateType = S;	;Set for appropriate StateType
triggerAll	=	Root, StateNo != [120,159] 
triggerall	=	Root, ctrl || Root, StateNo = 100
trigger1	=	random < 90
trigger1	=	Enemy, Time <= ceil(fvar(2) / 3)
trigger1	=	!InGuardDist&&!Root, InGuardDist         ;Not within guard distance
trigger1	=	P2StateNo = 5120
trigger2	=	!InGuardDist&&!Root, InGuardDist         ;Not within guard distance
trigger2	=	random < cond(P2StateNo >= 160, 120, 80)
Trigger2	=	P2MoveType != A
trigger2	=	Root, P2BodyDist X > 2*100
trigger3	=	!InGuardDist&&!Root, InGuardDist         ;Not within guard distance
Trigger3	=	Root, P2BodyDist X < 2*60
trigger3	=	Enemy, hitdefattr = , AT
trigger4	=	!Root, InGuardDist || InGuardDist         ;Not within guard distance
Trigger4	=	P2MoveType = A
trigger4	=	P2BodyDist X >= 2*30
Trigger4	=	Root, P2BodyDist X <= 2*140
;----------------------------------------------------------------------
Trigger1	=	pi||(fvar(0) := 40)
Trigger2	=	pi||(fvar(0) := 40)
Trigger3	=	pi||(fvar(0) := 40)
Trigger4	=	pi||(fvar(0) := 40)
;----------------------------------------------------------------------
Trigger1 = 0
Trigger2 = 0
Trigger3 = 0
Trigger4 = 0
Trigger5 = 0
Trigger6 = 0
Trigger7 = 0
Trigger8 = 0

[state 0, bind]
type=turn
Trigger1=facing!=Root, facing

[state 0, bind]
type=PosSet
Trigger1=1
X = 0
Y = 0

[State 0, AssertSpecial]
Type = AssertSpecial
Trigger1 = 1
Flag = Invisible
Flag = NoShadow

[State 0, NotHitBy]
Type = NotHitBy
Trigger1 = 1
Value = SCA,NA,SA,HA,NP,SP,HP,NT,ST,HT
Time = -1

[state -1, Variable Reset]
Type = VarAdd
IgnoreHitPause = 1
V = (0)
Trigger1 = var(0) > 0 
trigger1 = root, stateno != [6060,6062] 
Value = -1

[state -1, Variable Reset]
Type = VarSet
IgnoreHitPause = 1
fvar(1) = fvar(0)
trigger1 = fvar(0) != 0 

[state -1, WHAT ARE THEY DOING]
Type = VarSet
IgnoreHitPause = 1
fvar(2) = abs(enemy, animtime) + enemy, time
trigger1 = 1

[state -1, OW WHO DID THAT]
Type = VarSet
IgnoreHitPause = 1
fvar(3) = 10
trigger1 = Root, StateNo = [5000,5270]
Trigger1 = !fvar(3)
[state -1, Recently Hit Check]
Type = VarAdd
IgnoreHitPause = 1
fvar(3) = -1
trigger1 = Root, StateNo != [5000,5270]
Trigger1 = fvar(3) > 0
[state -1, Guard cancel]
Type = VarSet
IgnoreHitPause = 1
fvar(4) = 10
trigger1 = Root, StateNo = [6070,6072]
Trigger1 = !fvar(4)
[state -1, Recent Guard Cancel Check]
Type = VarAdd
IgnoreHitPause = 1
fvar(4) = -1
trigger1 = Root, StateNo != [6070,6072]
Trigger1 = fvar(4) > 0
[state -1, Guard Check]
Type = VarSet
IgnoreHitPause = 1
fvar(5) = 10
trigger1 = Root, StateNo = [150,159]
Trigger1 = !fvar(5)
[state -1, Recent Guard Check]
Type = VarAdd
IgnoreHitPause = 1
fvar(5) = -1
trigger1 = Root, StateNo != [120,159]
Trigger1 = fvar(5) > 0

[State -1, YOU WA PROJDETECT]
Type = Null
TriggerAll = 0
Trigger1 = 1
trigger2 = Time <= 10
Trigger3 = RoundState = 0
Trigger3 = Root, TeamMode = Simul || Enemy, TeamMode = Simul
Trigger4 = var(10) > 5 + var(11)
trigger5 = var(10) >= var(11)
trigger5 = playeridexist(var(10))
Trigger1 = var(10) := var(10) + 3
Trigger2 = var(11) := (Root, numhelper)+(enemy,numhelper)+(var(12))+(id)+1
Trigger3 = var(12) := var(12) + 1
Trigger4 = var(10) := var(11)
trigger5 = var(11) := var(10)
Trigger1 = 0
Trigger2 = 0
Trigger3 = 0
Trigger4 = 0
Trigger5 = 0

[State 0, Display To ClipBoard]
Type = DisplayToClipBoard
Text = "RootDist = %d, Enemy X,Y = %d %d, Enemy ATK: %d \naction = %d %d"
params = rootdist x, root,p2bodydist x,root,p2bodydist y, (P2MoveType = A) + (PlayerIdExist(var(10))) + Enemy, NumProj, fvar(0),fvar(1)
trigger1 = 1
[State 0, Display To ClipBoard]
Type = AppendToClipBoard
Text = " Cancel Buffer: %d GuDi?: %d P2ST: %d Vel: %d %d 57: %d"
params = var(0), InGuardDist + Root,InGuardDist,P2StateNo, root,vel x, root,vel y,var(57)
trigger1 = 1

; Don't remove the following line. It's required by the CMD standard.
[Statedef -1]

[State -3, Helper]
Type = Helper
TriggerAll	=	!IsHelper
Trigger1 	= 	!NumHelper(955531)
name = "Mio's AI"
ID = 955531
StateNo = 955531
pos = 0,0
posType = p1
facing = 1
ownpal = 0

[state -1, AI Jump]
Type = VarSet
IgnoreHitPause = 1
trigger1 = AILevel
Trigger1 = enemy, Vel X = 0
Trigger1 = P2StateType = A
Trigger1 = PrevStateNo != 100
sysvar(1) = 0

[state -1, AI Jump]
Type = VarSet
IgnoreHitPause = 1
triggerall = AILevel
Trigger1 = enemy, Vel X <= 0
trigger1 = p2bodydist x >= 120
trigger1 = p2statetype = S
Trigger1 = PrevStateNo != 100
trigger2 = prevstateno = 100
sysvar(1) = 1

;[State 0, AssertSpecial]
;Type = AssertSpecial
;IgnoreHitPause = 1
;Trigger1 = AILevel
;Flag = NoWalk
;Flag2 = NoStandGuard
;Flag3 = NoCrouchGuard
; 
;[State 0, AssertSpecial]
;Type = AssertSpecial
;Trigger1 = AILevel
;Flag = NoAirGuard
;IgnoreHitPause = 1

;[State -1, Jump Stop]
;type = ChangeState
;value = 0
;triggerAll = AILevel
;trigger1 = stateno = 40
;ctrl = 1

;===========================================================================
;This is not a move, but it sets up var(1) to be 1 if conditions are right
;for a combo into a special move (used below).
;Since a lot of special moves rely on the same conditions, this reduces
;redundant logic.
[State -1, Combo condition Reset]
type = VarSet
trigger1 = 1
var(1) = 0

[State -1, Combo condition Check]
type = VarSet
trigger1 = statetype != A
trigger1 = ctrl
trigger2 = (stateno = [200,299]) || (stateno = [400,499])
trigger2 = movecontact
var(1) = 1

;---------------------------------------------------------------------------
;Moe Moe Kyun! (Hyper)
[State -1, Moe Moe Kyun! (Hyper)]
type = ChangeState
value = 3050
triggerall = command = "MoeMoeKyun" && !AILevel || NumHelper(955531)&&helper(955531), fvar(0) = 3050
triggerall = power >= 3000
trigger1 = statetype = S
trigger1 = ctrl = 1
trigger2 = (stateno = [200,299]) || (stateno = [400,499])
trigger2 = movecontact

;---------------------------------------------------------------------------
;Deadly Syrup (Air) (Hyper)
[State -1, Deadly Syrup (Air) (Hyper)]
type = ChangeState
value = 3030
triggerall = command = "DeadlySyrupAir"&& !AILevel || NumHelper(955531)&&helper(955531), fvar(0) = 3030
triggerall = power >= 1000
trigger1 = statetype = A
trigger1 = ctrl = 1
trigger2 = (stateno = [600,640])
trigger2 = movecontact

;---------------------------------------------------------------------------
;Deadly Syrup (Hyper)
[State -1, Deadly Syrup (Hyper)]
type = ChangeState
value = 3020
triggerall = command = "DeadlySyrup" && !AILevel|| NumHelper(955531)&&helper(955531), fvar(0) = 3020
triggerall = power >= 1000
trigger1 = statetype = S
trigger1 = ctrl = 1
trigger2 = (stateno = [200,299]) || (stateno = [400,499])
trigger2 = movecontact

;---------------------------------------------------------------------------
;Hyper Sugar Crush (Hyper)
[State -1, Hyper Sugar Crush (Hyper)]
type = ChangeState
value = 3010
triggerall = command = "HyperSugarCrush"&& !AILevel|| NumHelper(955531)&&helper(955531), fvar(0) = 3010
triggerall = power >= 1000
trigger1 = statetype = S
trigger1 = ctrl = 1
trigger2 = (stateno = [200,299]) || (stateno = [400,499])
trigger2 = movecontact

;---------------------------------------------------------------------------
;Heartwave (Hyper)
[State -1, Heartwave (Hyper)]
type = ChangeState
value = 3000
triggerall = command = "Heartwave"&& !AILevel|| NumHelper(955531)&&helper(955531), fvar(0) = 3000
triggerall = power >= 1000
trigger1 = statetype = S
trigger1 = ctrl = 1
trigger2 = (stateno = [200,299]) || (stateno = [400,499])
trigger2 = movecontact

;---------------------------------------------------------------------------
;Heartbreak (EX)
[State -1, Heartbreak (EX)]
type = ChangeState
value = 1020
triggerall = command = "QCF_xy" && !AILevel|| NumHelper(955531)&&helper(955531), fvar(0) = 1020
triggerall = power >= 500
trigger1 = var(1) ;Use combo condition (above)

;---------------------------------------------------------------------------
;Heartbreak (Light)
[State -1, Heartbreak (Light)]
type = ChangeState
value = 1000
triggerall = !AILevel && command = "QCF_x" || NumHelper(955531)&&helper(955531), fvar(0) = 1000
trigger1 = var(1) ;Use combo condition (above)

;---------------------------------------------------------------------------
;Heartbreak (Strong)
[State -1, Heartbreak (Strong)]
type = ChangeState
value = 1010
triggerall = !AILevel && command = "QCF_y" || NumHelper(955531)&&helper(955531), fvar(0) = 1010
trigger1 = var(1) ;Use combo condition (above)

;---------------------------------------------------------------------------
;Roll Evade (EX)
[State -1, Roll Evade (EX)]
type = ChangeState
value = 1050
triggerall = !AILevel && command = "QCB_xy" || NumHelper(955531)&&helper(955531), fvar(0) = 1050
triggerall = power >= 500
trigger1 = var(1) ;Use combo condition (above)

;---------------------------------------------------------------------------
;Roll Evade (Light)
[State -1, Roll Evade (Light)]
type = ChangeState
value = 1030
triggerall = !AILevel && command = "QCB_x" || NumHelper(955531)&&helper(955531), fvar(0) = 1030
trigger1 = var(1) ;Use combo condition (above)

;---------------------------------------------------------------------------
;Roll Evade (Strong)
[State -1, Roll Evade (Strong)]
type = ChangeState
value = 1040
triggerall = !AILevel && command = "QCB_y" || NumHelper(955531)&&helper(955531), fvar(0) = 1040
trigger1 = var(1) ;Use combo condition (above)

;---------------------------------------------------------------------------
;Sugar Crush (EX)
[State -1, Sugar Crush (EX)]
type = ChangeState
value = 1120
triggerall = !AILevel && command = "QCF_ab" || NumHelper(955531)&&helper(955531), fvar(0) = 1120
triggerall = power >= 500
trigger1 = var(1) ;Use combo condition (above)

;---------------------------------------------------------------------------
;Sugar Crush (Light)
[State -1, Sugar Crush (Light)]
type = ChangeState
value = 1100
triggerall = !AILevel && command = "QCF_a"|| NumHelper(955531)&&helper(955531), fvar(0) = 1100
trigger1 = var(1) ;Use combo condition (above)

;---------------------------------------------------------------------------
;Sugar Crush (Strong)
[State -1, Sugar Crush (Strong)]
type = ChangeState
value = 1110
triggerall = !AILevel && command = "QCF_b"|| NumHelper(955531)&&helper(955531), fvar(0) = 1110
trigger1 = var(1) ;Use combo condition (above)

;---------------------------------------------------------------------------
;Serious Tuning (Light)
[State -1, Serious Tuning (Light)]
type = ChangeState
value = 1150
triggerall = NumHelper(955531)&&helper(955531), fvar(0) = 1150 ||!AILevel && command = "HCB_a"
trigger1 = var(1) ;Use combo condition (above)

;---------------------------------------------------------------------------
;Serious Tuning (Light)
[State -1, Serious Tuning (Strong)]
type = ChangeState
value = 1160
triggerall = NumHelper(955531)&&helper(955531), fvar(0) = 1160 ||!AILevel && command = "HCB_b"
trigger1 = var(1) ;Use combo condition (above)

;---------------------------------------------------------------------------
;Teleportation (Light)
[State -1, Teleportation (Light)]
type = ChangeState
value = 1130
triggerall = NumHelper(955531)&&helper(955531), fvar(0) = 1130 ||!AILevel && command = "QCB_a"
trigger1 = var(1) ;Use combo condition (above)

;---------------------------------------------------------------------------
;Teleportation (Light)
[State -1, Teleportation (Strong)]
type = ChangeState
value = 1140
triggerall = NumHelper(955531)&&helper(955531), fvar(0) = 1140||!AILevel && command = "QCB_b"
trigger1 = var(1) ;Use combo condition (above)

;---------------------------------------------------------------------------
;Maple Honey (EX)
[State -1, Maple Honey (EX)]
type = ChangeState
value = 1220
triggerall = NumHelper(955531)&&helper(955531), fvar(0) = 1220||!AILevel && command = "QCF_ab"
triggerall = power >= 500
trigger1 = statetype = A
trigger1 = ctrl
trigger2 = (stateno = 600 || stateno = 610 || stateno = 630 || stateno = 640) && movecontact

;---------------------------------------------------------------------------
;Maple Honey (Light)
[State -1, Maple Honey (Light)]
type = ChangeState
value = 1200
triggerall = NumHelper(955531)&&helper(955531), fvar(0) = 1200||!AILevel && command = "QCF_a"
trigger1 = statetype = A
trigger1 = ctrl
trigger2 = (stateno = 600 || stateno = 610 || stateno = 630 || stateno = 640) && movecontact

;---------------------------------------------------------------------------
;Maple Honey (Strong)
[State -1, Maple Honey (Strong)]
type = ChangeState
value = 1210
triggerall = NumHelper(955531)&&helper(955531), fvar(0) = 1210||!AILevel && command = "QCF_b"
trigger1 = statetype = A
trigger1 = ctrl
trigger2 = (stateno = 600 || stateno = 610 || stateno = 630 || stateno = 640) && movecontact

;===========================================================================
;---------------------------------------------------------------------------
;Run Fwd
[State -1, Run Fwd]
type = ChangeState
value = 100
trigger1 = !AILevel && command = "FF"
trigger1 = statetype = S
trigger1 = ctrl

;Run Fwd
[State -1, Run Fwd]
type = ChangeState
value = 100
trigger1 = NumHelper(955531)&&helper(955531), fvar(0) = 100
trigger1 = statetype != A
trigger1 = ctrl

;---------------------------------------------------------------------------
;Run Back
[State -1, Run Back]
type = ChangeState
value = 105
trigger1 = NumHelper(955531)&&helper(955531), fvar(0) = 105||!AILevel && command = "BB"
trigger1 = statetype = S
trigger1 = ctrl

;---------------------------------------------------------------------------
;Choke Lift
[State -1, Choke Lift]
type = ChangeState
value = 800
triggerall = command = "y" && !AILevel
triggerall = statetype = S
triggerall = ctrl
triggerall = stateno != 100
trigger1 = command = "holdfwd"
trigger1 = p2bodydist X < 3
trigger1 = (p2statetype = S) || (p2statetype = C)
trigger1 = p2movetype != H
trigger2 = command = "holdback"
trigger2 = p2bodydist X < 5
trigger2 = (p2statetype = S) || (p2statetype = C)
trigger2 = p2movetype != H;Choke Lift
[State -1, Choke Lift]
type = ChangeState
value = 800
triggerall = NumHelper(955531)&&helper(955531), fvar(0) = 800
triggerall = statetype = S
triggerall = ctrl || stateno = 20
triggerall = stateno != 100
trigger1 = p2bodydist X < 5
trigger1 = (p2statetype = S) || (p2statetype = C)
trigger1 = p2movetype != H

;===========================================================================
;---------------------------------------------------------------------------
;Stand Light Punch
[State -1, Stand Light Punch]
type = ChangeState
value = 200
triggerall = command = "x"&& !AILevel
triggerall = command != "holddown"
trigger1 = statetype = S
trigger1 = ctrl
trigger2 = stateno = 200 
trigger2 = time > 10

;---------------------------------------------------------------------------
;Stand Strong Punch
[State -1, Stand Strong Punch]
type = ChangeState
value = 210
triggerall = command = "y"&& !AILevel
triggerall = command != "holddown"
trigger1 = statetype = S
trigger1 = ctrl
trigger2 = (stateno = 200 || stateno = 230 || stateno = 400 || stateno = 430) && movecontact

;---------------------------------------------------------------------------
;Stand Light Kick
[State -1, Stand Light Kick]
type = ChangeState
value = 230
triggerall = command = "a"&& !AILevel
triggerall = command != "holdfwd"
trigger1 = statetype = S
trigger1 = ctrl
trigger2 = stateno = 230
trigger2 = time > 22

;---------------------------------------------------------------------------
;Standing Double Kick
[State -1, Standing Double Kick]
type = ChangeState
value = 235
triggerall = command = "a"&& !AILevel
triggerall = command = "holdfwd"
trigger1 = statetype = S
trigger1 = ctrl
trigger2 = (stateno = 200 || stateno = 230 || stateno = 400 || stateno = 430) && movecontact

;---------------------------------------------------------------------------
;Standing Strong Kick
[State -1, Standing Strong Kick]
type = ChangeState
value = 240
triggerall = command = "b"&& !AILevel
triggerall = command != "holddown"
trigger1 = statetype = S
trigger1 = ctrl
trigger2 = (stateno = 200 || stateno = 230 || stateno = 400 || stateno = 430) && movecontact

;---------------------------------------------------------------------------
;Taunt
[State -1, Taunt]
type = ChangeState
value = 195
triggerall = command = "start"&& !AILevel
trigger1 = statetype != A
trigger1 = ctrl

;---------------------------------------------------------------------------
;Crouching Light Punch
[State -1, Crouching Light Punch]
type = ChangeState
value = 400
triggerall = command = "x"&& !AILevel
triggerall = command = "holddown"
trigger1 = statetype = C
trigger1 = ctrl
trigger2 = stateno = 400
trigger2 = time > 15

;---------------------------------------------------------------------------
;Crouching Strong Punch
[State -1, Crouching Strong Punch]
type = ChangeState
value = 410
triggerall = command = "y"&& !AILevel
triggerall = command = "holddown"
trigger1 = statetype = C
trigger1 = ctrl
trigger2 = (stateno = 200 || stateno = 230 || stateno = 400 || stateno = 430) && movecontact

;---------------------------------------------------------------------------
;Crouching Light Kick
[State -1, Crouching Light Kick]
type = ChangeState
value = 430
triggerall = command = "a"&& !AILevel
triggerall = command = "holddown"
trigger1 = statetype = C
trigger1 = ctrl
trigger2 = stateno = 430 
trigger2 = time > 15

;---------------------------------------------------------------------------
;Crouching Strong Kick
[State -1, Crouching Slide Kick]
type = ChangeState
value = 440
triggerall = command = "b"&& !AILevel
triggerall = command = "holddown"
trigger1 = statetype = C
trigger1 = ctrl
trigger2 = (stateno = 200 || stateno = 230 || stateno = 400 || stateno = 430) && movecontact

;---------------------------------------------------------------------------
;Jump Light Punch
[State -1, Jump Light Punch]
type = ChangeState
value = 600
triggerall = command = "x"&& !AILevel || NumHelper(955531)&&helper(955531), fvar(0) = 600
trigger1 = statetype = A
trigger1 = ctrl = 1
trigger2 = stateno = 600
trigger2 = time > 12

;---------------------------------------------------------------------------
;Jump Strong Punch
[State -1, Jump Strong Punch]
type = ChangeState
value = 610
triggerall = command = "y"&& !AILevel || NumHelper(955531)&&helper(955531), fvar(0) = 610
trigger1 = statetype = A
trigger1 = ctrl
trigger2 = (stateno = 600 || stateno = 630) && movecontact

;---------------------------------------------------------------------------
;Jump Light Kick
[State -1, Jump Light Kick]
type = ChangeState
value = 630
triggerall = command = "a"&& !AILevel || NumHelper(955531)&&helper(955531), fvar(0) = 630
trigger1 = statetype = A
trigger1 = ctrl 
trigger2 = stateno = 630
trigger2 = time > 15

;---------------------------------------------------------------------------
;Jump Strong Kick
[State -1, Jump Strong Kick]
type = ChangeState
value = 640
triggerall = command = "b"&& !AILevel || NumHelper(955531)&&helper(955531), fvar(0) = 640
trigger1 = statetype = A
trigger1 = ctrl
trigger2 = (stateno = 600 || stateno = 630) && movecontact

;---------------------------------------------------------------------------
; Dizzy Cancel (Stand)
[State -1, |Dizzy Cancel Stand|]
type = ChangeState
value = 6060+(statetype = S)
triggerall =  movetype != H
triggerall = statetype != C
triggerall = var(3) < 3
triggerall = command = "c"&& !AILevel || NumHelper(955531)&&helper(955531), fvar(0) = 6060
triggerall = power > 500
trigger1 = (stateno = [600,699]) || (stateno = [1201,1211])
trigger1 = movehit
trigger2 = (stateno = [200,499]) || (stateno = [1100,1110]) || stateno = 1152 || stateno = 1300
trigger2 = movehit
trigger3 = numhelper(1001)
trigger3 = helper(1001),movehit
trigger4 = numhelper(1011)
trigger4 = helper(1011),movehit
;---------------------------------------------------------------------------
; Dizzy Cancel (Crouch)
[State -1, |Dizzy Cancel Crouch|]
type = ChangeState
value = 6062
triggerall =  movetype != H
triggerall = statetype = C
triggerall = var(3) < 3
triggerall = command = "c"&& !AILevel || NumHelper(955531)&&helper(955531), fvar(0) = 6061
triggerall = power > 500
trigger1 = (stateno = [600,699]) || (stateno = [1201,1211])
trigger1 = movehit
trigger2 = (stateno = [200,499]) || (stateno = [1100,1110]) || stateno = 1152 || stateno = 1300 
trigger2 = movehit
trigger3 = numhelper(1001)
trigger3 = helper(1001),movehit
trigger4 = numhelper(1011)
trigger4 = helper(1011),movehit

;---------------------------------------------------------------------------
; Dizzy Guard Cancel (Air)
[State -1, |Dizzy Guard Cancel Air|]
type = ChangeState
value = 6070
triggerall =  movetype = H
triggerall = statetype = A
triggerall = command = "z" && power > 1000
trigger1 = stateno = 154

;---------------------------------------------------------------------------
; Dizzy Guard Cancel (Stand)
[State -1, |Dizzy Guard Cancel Stand|]
type = ChangeState
value = 6071
triggerall =  movetype = H
triggerall = statetype = S
triggerall = command = "z" && !AILevel || AILevel && random <= 80
triggerall = power > 1000
trigger1 = stateno = 150

;---------------------------------------------------------------------------
; Dizzy Guard Cancel (Crouch)
[State -1, |Dizzy Guard Cancel Crouch|]
type = ChangeState
value = 6072
triggerall =  movetype = H
triggerall = statetype = C
triggerall = command = "z" && !AILevel || AILevel && random <= 80
triggerall = power > 1000
trigger1 = stateno = 152

;---------------------------------------------------------------------------

;===========================================================================
;---------------------------------------------------------------------------
;Stand Light Punch
[State -1, Stand Light Punch]
type = ChangeState
value = 200
triggerall = NumHelper(955531)&&helper(955531), fvar(0) = 200
trigger1 = statetype != A
trigger1 = ctrl
trigger2 = stateno = 200 
trigger2 = time > 10

;---------------------------------------------------------------------------
;Stand Strong Punch
[State -1, Stand Strong Punch]
type = ChangeState
value = 210
triggerall = NumHelper(955531)&&helper(955531), fvar(0) = 210
trigger1 = statetype != A
trigger1 = ctrl
trigger2 = (stateno = 200 || stateno = 230 || stateno = 400 || stateno = 430) && movecontact

;---------------------------------------------------------------------------
;Stand Light Kick
[State -1, Stand Light Kick]
type = ChangeState
value = 230
triggerall = NumHelper(955531)&&helper(955531), fvar(0) = 230
trigger1 = statetype != A
trigger1 = ctrl
trigger2 = stateno = 230
trigger2 = time > 22

;---------------------------------------------------------------------------
;Standing Double Kick
[State -1, Standing Double Kick]
type = ChangeState
value = 235
triggerall = NumHelper(955531)&&helper(955531), fvar(0) = 235
trigger1 = statetype != A
trigger1 = ctrl
trigger2 = (stateno = 200 || stateno = 230 || stateno = 400 || stateno = 430) && movecontact

;---------------------------------------------------------------------------
;Standing Strong Kick
[State -1, Standing Strong Kick]
type = ChangeState
value = 240
triggerall = NumHelper(955531)&&helper(955531), fvar(0) = 240
trigger1 = statetype != A
trigger1 = ctrl
trigger2 = (stateno = 200 || stateno = 230 || stateno = 400 || stateno = 430) && movecontact


;---------------------------------------------------------------------------
;Crouching Light Punch
[State -1, Crouching Light Punch]
type = ChangeState
value = 400
triggerall = NumHelper(955531)&&helper(955531), fvar(0) = 400
trigger1 = statetype != A
trigger1 = ctrl
trigger2 = stateno = 400
trigger2 = time > 15

;---------------------------------------------------------------------------
;Crouching Strong Punch
[State -1, Crouching Strong Punch]
type = ChangeState
value = 410
triggerall = NumHelper(955531)&&helper(955531), fvar(0) = 410
trigger1 = statetype != A
trigger1 = ctrl
trigger2 = (stateno = 200 || stateno = 230 || stateno = 400 || stateno = 430) && movecontact

;---------------------------------------------------------------------------
;Crouching Light Kick
[State -1, Crouching Light Kick]
type = ChangeState
value = 430
triggerall = NumHelper(955531)&&helper(955531), fvar(0) = 430
trigger1 = statetype != A
trigger1 = ctrl
trigger2 = stateno = 430 
trigger2 = time > 15

;---------------------------------------------------------------------------
;Crouching Strong Kick
[State -1, Crouching Slide Kick]
type = ChangeState
value = 440
triggerall = NumHelper(955531)&&helper(955531), fvar(0) = 440
trigger1 = statetype != A
trigger1 = ctrl
trigger2 = (stateno = 200 || stateno = 230 || stateno = 400 || stateno = 430) && movecontact

[State -3, Jump Light Kick]
type = ChangeState
Value = 40
triggerall = AILevel 
TriggerAll = StateType != A
TriggerAll = Helper(955531), fvar(0) = 40
TriggerAll = Helper(955531), fvar(1) = 40
trigger1 = Ctrl || StateNo = 100

[State -3, Jump Light Kick]
type = ChangeState
value = 120
triggerall = AILevel
triggerall = numenemy
triggerall = roundstate = 2
triggerall = alive
triggerall = Ctrl || StateNo = 20
trigger1 = InGuardDist
trigger2 = enemy, time <= 40
trigger2 = p2movetype = A
trigger2 = p2stateno >= 3000

[State -3, Jump Light Kick]
type = null;ChangeState
value = 130
triggerall =AILevel
triggerall = statetype = C
triggerall = stateno = 120 || stateno = 131
trigger2 = p2statetype = A 
trigger1 = helper(955531), fvar(2) / 4 > 7 
trigger1 = P2StateType = S

[State -3, Jump Light Kick]
type = null;ChangeState
value = 131
triggerall =AILevel
triggerall = statetype = S
triggerall = stateno = 120 || stateno = 130
trigger2 = p2statetype != A 
trigger2 = helper(955531), fvar(2) / 4 <= 7 
trigger1 = P2StateType = C

[State -3, Jump Light Kick]
type = ChangeState
Value = 20
triggerall = AILevel
triggerall = statetype != A
triggerAll = Ctrl
triggerall = stateno != 100
triggerall = stateno != 20
Trigger1 = Helper(955531), var(59)
Trigger2 = Helper(955531), var(57)

[State -1, Jump Lock]
type = ChangeState
value = 0
CTRL = 1
triggerall = AILevel
triggerall = statetype != A
Trigger1 = Helper(955531), fvar(1) != 40
Trigger1 = Helper(955531), fvar(0) != 40
trigger1 = stateno = 40
